跳到主要内容

BmpString

搜索

结构体 BmpString 

pub struct BmpString(/* private fields */);
展开描述

ASN.1 BMPString 类型。

示例

你可以使用 BmpString::try_from字符串字面量 创建一个 BmpString

use rcgen::string::BmpString;
let hello = BmpString::try_from("hello").unwrap();

支持的字符

对 Unicode 基本多文种平面(BMP)子集(ISO 10646),即 UCS-2 进行编码。

字节以 UTF-16 大端序编码。

之所以保留 BMPString 仅为向后兼容,RFC 5280 建议不要将其用于新主体的证书。

实现

Source

impl BmpString

pub fn as_bytes(&self) -> &[u8]

返回该 BmpString 内容对应的字节切片。

本方法的反操作是 from_utf16be

示例
use rcgen::string::BmpString;
let s = BmpString::try_from("hello").unwrap();

assert_eq!(&[0, 104, 0, 101, 0, 108, 0, 108, 0, 111], s.as_bytes());
pub fn from_utf16be(vec: Vec<u8>) -> Result<Self, Error>

将一个 UTF-16BE 编码的向量 vec 解码为 BmpString,若 vec 中含有任何非法数据则返回 Err

Trait 实现

Source

impl Clone for BmpString

Source

fn clone(&self) -> BmpString

返回值的副本。 更多信息
1.0.0 · Source

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
Source

impl Debug for BmpString

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl FromStr for BmpString

Source

type Err = Error

The associated error which can be returned from parsing.
Source

fn from_str(s: &str) -> Result<Self, Self::Err>

Parses a string s to return a value of this type. 更多信息
Source

impl Hash for BmpString

Source

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 更多信息
1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 更多信息
Source

impl PartialEq for BmpString

Source

fn eq(&self, other: &BmpString) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

测试 != 运算符。默认实现几乎总是够用,除非有非常充分的理由,否则不应被覆盖。
Source

impl TryFrom<&str> for BmpString

Source

fn try_from(value: &str) -> Result<Self, Self::Error>

将一个 &str 转换为 BmpString

任何不属于 BmpString 字符集的字符都将被拒绝。 更多信息请参见 BmpString 文档。

结果将在堆上分配。

Source

type Error = Error

转换出错时返回的类型。
Source

impl TryFrom<String> for BmpString

Source

fn try_from(value: String) -> Result<Self, Self::Error>

将一个 String 转换为 BmpString

任何不属于 BmpString 字符集的字符都将被拒绝。 更多信息请参见 BmpString 文档。

解析 BmpString 时会进行内存分配,因为 UTF-8 到 UTF-16 的转换需要一次内存分配。

Source

type Error = Error

转换出错时返回的类型。
Source

impl Eq for BmpString

Source

impl StructuralPartialEq for BmpString

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> CloneToUninit for T
where T: Clone,

Source

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

Source

impl<T> ToOwned for T
where T: Clone,

Source

type Owned = T

获得所有权后的类型。
Source

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
Source

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。