跳到主要内容

UniversalString

搜索

结构体 UniversalString 

pub struct UniversalString(/* private fields */);
展开描述

ASN.1 UniversalString 类型。

示例

你可以使用 UniversalString::try_from字面量字符串 创建 UniversalString

use rcgen::string::UniversalString;
let hello = UniversalString::try_from("hello").unwrap();

支持的字符

UniversalString 类型可出现的字符是 ISO/IEC 10646(Unicode)所允许的任何字符。

字节以 UTF-32 大端序编码。

包含 UniversalString 是为了向后兼容;RFC 5280 规定它不应被用于新证书的主体。

实现

Source

impl UniversalString

pub fn as_bytes(&self) -> &[u8]

返回该 UniversalString 内容对应的字节切片。

该方法的逆操作是 from_utf32be

示例
use rcgen::string::UniversalString;
let s = UniversalString::try_from("hello").unwrap();

assert_eq!(&[0, 0, 0, 104, 0, 0, 0, 101, 0, 0, 0, 108, 0, 0, 0, 108, 0, 0, 0, 111], s.as_bytes());
pub fn from_utf32be(vec: Vec<u8>) -> Result<UniversalString, Error>

将一个 UTF-32BE 编码的向量 vec 解码为 UniversalString,若 vec 中含有任何非法数据则返回 Err

Trait 实现

Source

impl Clone for UniversalString

Source

fn clone(&self) -> UniversalString

返回值的副本。 更多信息
1.0.0 · Source

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
Source

impl Debug for UniversalString

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl Hash for UniversalString

Source

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 更多信息
1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 更多信息
Source

impl PartialEq for UniversalString

Source

fn eq(&self, other: &UniversalString) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

测试 != 运算符。默认实现几乎总是够用,除非有非常充分的理由,否则不应被覆盖。
Source

impl TryFrom<&str> for UniversalString

Source

fn try_from(value: &str) -> Result<Self, Self::Error>

将一个 &str 转换为 UniversalString

任何不属于 UniversalString 字符集的字符都将被拒绝。 更多信息请参见 UniversalString 文档。

结果分配在堆上。

Source

type Error = Error

转换出错时返回的类型。
Source

impl TryFrom<String> for UniversalString

Source

fn try_from(value: String) -> Result<Self, Self::Error>

将一个 String 转换为 UniversalString

任何不属于 UniversalString 字符集的字符都将被拒绝。 更多信息请参见 UniversalString 文档。

解析 UniversalString 会分配内存,因为 UTF-8 到 UTF-32 的转换需要一次内存分配。

Source

type Error = Error

转换出错时返回的类型。
Source

impl Eq for UniversalString

Source

impl StructuralPartialEq for UniversalString

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> CloneToUninit for T
where T: Clone,

Source

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

Source

impl<T> ToOwned for T
where T: Clone,

Source

type Owned = T

获得所有权后的类型。
Source

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
Source

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。